@@ -2,13 +2,13 @@ import pandas as pd
 from cachetools import TTLCache, cached
 from komoutils.core import KomoBase
 
-from aporacle import MONGODB_URI, MONGODB_NAME
+from aporacle import conf
 from aporacle.data.db.crud import Crud
 
 
 class SymbolData(KomoBase):
     def __init__(self):
-        self.crud: Crud = Crud(uri=MONGODB_URI, db_name=MONGODB_NAME)
+        self.crud: Crud = Crud(uri=conf.mongo_database_uri, db_name=conf.mongo_database_name)
 
     @cached(cache=TTLCache(maxsize=1024, ttl=3600))
     def get_symbol(self, symbol: str) -> list:
