@@ -95,7 +95,7 @@ class VotingRoundExecutable(KomoBase):
                         # print("Waiting for message")
                         data = await websocket.recv()
                         message = json.loads(data)
-                        print(message)
+                        # print(message)
                         if 'success' in message:
                             continue
 
@@ -108,7 +108,7 @@ class VotingRoundExecutable(KomoBase):
                                                 msg=f"Waiting for the next TSO schedule message. ")
                             continue
 
-                        print(message)
+                        # print(message)
                         self.utilities_message_processor(message=message)
 
                     except websockets.ConnectionClosed as cc:
